@@ -1,5 +1,6 @@
 package App::GitGot::Command;
-$App::GitGot::Command::VERSION = '1.330';
+our $AUTHORITY = 'cpan:GENEHACK';
+$App::GitGot::Command::VERSION = '1.332';
 # ABSTRACT: Base class for App::GitGot commands
 use 5.014;
 
@@ -376,6 +377,9 @@ sub _git_status {
 
   $msg .= $self->_run_git_cherry( $entry )
     if $entry->current_remote_branch;
+  if ($self->opt->show_branch and defined $entry->current_branch) {
+      $msg .= '[' . $entry->current_branch . ']';
+  }
 
   return ( $self->verbose ) ? "$msg$verbose_msg" : $msg;
 }
@@ -582,7 +586,7 @@ App::GitGot::Command - Base class for App::GitGot commands
 
 =head1 VERSION
 
-version 1.330
+version 1.332
 
 =head1 METHODS
 
