@@ -1,5 +1,6 @@
 package App::GitGot::Command::status;
-$App::GitGot::Command::status::VERSION = '1.330';
+our $AUTHORITY = 'cpan:GENEHACK';
+$App::GitGot::Command::status::VERSION = '1.332';
 # ABSTRACT: print status info about repos
 use 5.014;
 
@@ -9,6 +10,14 @@ use namespace::autoclean;
 
 sub command_names { qw/ status st / }
 
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'show-branch' => 'show which branch' => { default => 0 } ] ,
+  );
+}
+
+
 sub _execute {
   my ( $self, $opt, $args ) = @_;
 
@@ -31,7 +40,7 @@ App::GitGot::Command::status - print status info about repos
 
 =head1 VERSION
 
-version 1.330
+version 1.332
 
 =head1 AUTHOR
 
